package com.sun.media.sound;

import javax.sound.sampled.AudioFormat;
import javax.sound.midi.MidiChannel;
import javax.sound.midi.Patch;
import javax.sound.midi.Soundbank;
import javax.sound.midi.Instrument;

public abstract class ModelInstrument extends Instrument
{
    protected ModelInstrument(Soundbank soundbank, Patch patch, String name, Class<?> dataClass) {
        super(soundbank, patch, name, dataClass);
    }
    
    public ModelDirector getDirector(ModelPerformer[] array, MidiChannel midiChannel, ModelDirectedPlayer modelDirectedPlayer) {
        return new ModelStandardIndexedDirector(array, modelDirectedPlayer);
    }
    
    public ModelPerformer[] getPerformers() {
        return new ModelPerformer[0];
    }
    
    public ModelChannelMixer getChannelMixer(MidiChannel midiChannel, AudioFormat audioFormat) {
        return null;
    }
    
    public final Patch getPatchAlias() {
        Patch patch = this.getPatch();
        int program = patch.getProgram();
        if (patch.getBank() != 0) {
            return patch;
        }
        boolean percussion = false;
        if ((this.getPatch() instanceof ModelPatch)) {
            percussion = ((ModelPatch)this.getPatch()).isPercussion();
        }
        if (!(percussion == 0)) {
            return new Patch(15360, program);
        }
        return new Patch(15488, program);
    }
    
    public final String[] getKeys() {
        String[] array = new String[128];
        for (ModelPerformer modelPerformer : this.getPerformers()) {
            for (int j = modelPerformer.getKeyFrom(); j <= modelPerformer.getKeyTo(); ++j) {
                if (j >= 0 && j < 128 && array[j] == null) {
                    String name = modelPerformer.getName();
                    if (name == null) {
                        name = "untitled";
                    }
                    array[j] = name;
                }
            }
        }
        return array;
    }
    
    public final boolean[] getChannels() {
        boolean percussion = false;
        if ((this.getPatch() instanceof ModelPatch)) {
            percussion = ((ModelPatch)this.getPatch()).isPercussion();
        }
        if (!(percussion == 0)) {
            boolean[] array3 = new boolean[16];
            for (int k = 0; k < array3.length; ++k) {
                array3[k] = false;
            }
            array3[9] = true;
            return array3;
        }
        int bank = this.getPatch().getBank();
        if (bank >> 7 == 120 || bank >> 7 == 121) {
            boolean[] array2 = new boolean[16];
            for (int j = 0; j < array2.length; ++j) {
                array2[j] = true;
            }
            return array2;
        }
        boolean[] array = new boolean[16];
        for (int i = 0; i < array.length; ++i) {
            array[i] = true;
        }
        array[9] = false;
        return array;
    }
}
